You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by ce...@apache.org on 2012/02/13 17:35:47 UTC

svn commit: r1243595 - in /commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform: DctNormalization.java DftNormalization.java DstNormalization.java FastSineTransformer.java

Author: celestin
Date: Mon Feb 13 16:35:46 2012
New Revision: 1243595

URL: http://svn.apache.org/viewvc?rev=1243595&view=rev
Log:
In package o.a.c.m.transform, created enum DstNormalization to be passed to the constructor of FastSineTransformer (instead of boolean parameter).
Made constructor public, and removed factory methods.
See MATH-743

Added:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DstNormalization.java   (with props)
Modified:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DctNormalization.java
    commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DftNormalization.java
    commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/FastSineTransformer.java

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DctNormalization.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DctNormalization.java?rev=1243595&r1=1243594&r2=1243595&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DctNormalization.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DctNormalization.java Mon Feb 13 16:35:46 2012
@@ -22,7 +22,7 @@ package org.apache.commons.math.transfor
  * normalizations is detailed below.
  *
  * @see FastCosineTransformer
- * @version $Id Revision$
+ * @version $Id$
  * @since 3.0
  */
 public enum DctNormalization {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DftNormalization.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DftNormalization.java?rev=1243595&r1=1243594&r2=1243595&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DftNormalization.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DftNormalization.java Mon Feb 13 16:35:46 2012
@@ -22,7 +22,7 @@ package org.apache.commons.math.transfor
  * normalizations is detailed below.
  *
  * @see FastFourierTransformer
- * @version $Id Revision$
+ * @version $Id$
  * @since 3.0
  */
 public enum DftNormalization {

Added: commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DstNormalization.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DstNormalization.java?rev=1243595&view=auto
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DstNormalization.java (added)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DstNormalization.java Mon Feb 13 16:35:46 2012
@@ -0,0 +1,61 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.commons.math.transform;
+
+/**
+ * This enumeration defines the various types of normalizations that can be
+ * applied to discrete sine transforms (DST). The exact definition of these
+ * normalizations is detailed below.
+ *
+ * @see FastSineTransformer
+ * @version $Id$
+ * @since 3.0
+ */
+public enum DstNormalization {
+    /**
+     * <p>
+     * Should be passed to the constructor of {@link FastSineTransformer} to
+     * use the <em>standard</em> normalization convention. The standard DST-I
+     * normalization convention is defined as follows
+     * <ul>
+     * <li>forward transform: y<sub>n</sub> = &sum;<sub>k=0</sub><sup>N-1</sup>
+     * x<sub>k</sub> sin(&pi; nk / N),</li>
+     * <li>inverse transform: x<sub>k</sub> = (2 / N)
+     * &sum;<sub>n=0</sub><sup>N-1</sup> y<sub>n</sub> sin(&pi; nk / N),</li>
+     * </ul>
+     * where N is the size of the data sample, and x<sub>0</sub> = 0.
+     * </p>
+     */
+    STANDARD_DST_I,
+
+    /**
+     * <p>
+     * Should be passed to the constructor of {@link FastSineTransformer} to
+     * use the <em>orthogonal</em> normalization convention. The orthogonal
+     * DCT-I normalization convention is defined as follows
+     * <ul>
+     * <li>Forward transform: y<sub>n</sub> = &radic;(2 / N)
+     * &sum;<sub>k=0</sub><sup>N-1</sup> x<sub>k</sub> sin(&pi; nk / N),</li>
+     * <li>Inverse transform: x<sub>k</sub> = &radic;(2 / N)
+     * &sum;<sub>n=0</sub><sup>N-1</sup> y<sub>n</sub> sin(&pi; nk / N),</li>
+     * </ul>
+     * which makes the transform orthogonal. N is the size of the data sample,
+     * and x<sub>0</sub> = 0.
+     * </p>
+     */
+    ORTHOGONAL_DST_I
+}

Propchange: commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DstNormalization.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/DstNormalization.java
------------------------------------------------------------------------------
    svn:keywords = Id Revision

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/FastSineTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/FastSineTransformer.java?rev=1243595&r1=1243594&r2=1243595&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/FastSineTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math/transform/FastSineTransformer.java Mon Feb 13 16:35:46 2012
@@ -35,42 +35,10 @@ import org.apache.commons.math.util.Fast
  * <p>
  * There are several variants of the discrete sine transform. The present
  * implementation corresponds to DST-I, with various normalization conventions,
  * which are described below. <strong>It should be noted that regardless to the
  * convention, the first element of the dataset to be transformed must be
  * zero.</strong>
  * </p>
- * <h3><a id="standard">Standard DST-I</a></h3>
- * <p>
- * The standard normalization convention is defined as follows
- * <ul>
- * <li>forward transform: y<sub>n</sub> = &sum;<sub>k=0</sub><sup>N-1</sup>
- * x<sub>k</sub> sin(&pi; nk / N),</li>
- * <li>inverse transform: x<sub>k</sub> = (2 / N)
- * &sum;<sub>n=0</sub><sup>N-1</sup> y<sub>n</sub> sin(&pi; nk / N),</li>
- * </ul>
- * where N is the size of the data sample, and x<sub>0</sub> = 0.
- * </p>
- * <p>
- * {@link RealTransformer}s following this convention are returned by the
- * factory method {@link #create()}.
- * </p>
- * <h3><a id="orthogonal">Orthogonal DST-I</a></h3>
- * <p>
- * The orthogonal normalization convention is defined as follows
- * <ul>
- * <li>Forward transform: y<sub>n</sub> = &radic;(2 / N)
- * &sum;<sub>k=0</sub><sup>N-1</sup> x<sub>k</sub> sin(&pi; nk / N),</li>
- * <li>Inverse transform: x<sub>k</sub> = &radic;(2 / N)
- * &sum;<sub>n=0</sub><sup>N-1</sup> y<sub>n</sub> sin(&pi; nk / N),</li>
- * </ul>
- * which makes the transform orthogonal. N is the size of the data sample, and
- * x<sub>0</sub> = 0.
- * </p>
- * <p>
- * {@link RealTransformer}s following this convention are returned by the
- * factory method {@link #createOrthogonal()}.
- * </p>
- * <h3>Link with the DFT, and assumptions on the layout of the data set</h3>
  * <p>
  * DST-I is equivalent to DFT of an <em>odd extension</em> of the data series.
  * More precisely, if x<sub>0</sub>, &hellip;, x<sub>N-1</sub> is the data set
@@ -104,7 +72,7 @@ import org.apache.commons.math.util.Fast
  * sampling.
  * </p>
  *
- * @version $Id: FastSineTransformer.java 1213157 2011-12-12 07:19:23Z celestin$
+ * @version $Id$
  * @since 1.2
  */
 public class FastSineTransformer implements RealTransformer, Serializable {
@@ -112,50 +80,18 @@ public class FastSineTransformer impleme
     /** Serializable version identifier. */
     static final long serialVersionUID = 20120211L;
 
-    /**
-     * {@code true} if the orthogonal version of the DCT should be used.
-     *
-     * @see #create()
-     * @see #createOrthogonal()
-     */
-    private final boolean orthogonal;
+    /** The type of DST to be performed. */
+    private final DstNormalization normalization;
 
     /**
      * Creates a new instance of this class, with various normalization
      * conventions.
      *
-     * @param orthogonal {@code false} if the DST is <em>not</em> to be scaled,
-     * {@code true} if it is to be scaled so as to make the transform
-     * orthogonal.
-     * @see #create()
-     * @see #createOrthogonal()
-     */
-    private FastSineTransformer(final boolean orthogonal) {
-        this.orthogonal = orthogonal;
-    }
-
-    /**
-     * <p>
-     * Returns a new instance of this class. The returned transformer uses the
-     * <a href="#standard">standard normalizing conventions</a>.
-     * </p>
-     *
-     * @return a new DST transformer, with standard normalizing conventions
-     */
-    public static FastSineTransformer create() {
-        return new FastSineTransformer(false);
-    }
-
-    /**
-     * <p>
-     * Returns a new instance of this class. The returned transformer uses the
-     * <a href="#orthogonal">orthogonal normalizing conventions</a>.
-     * </p>
-     *
-     * @return a new DST transformer, with orthogonal normalizing conventions
+     * @param normalization the type of normalization to be applied to the
+     * transformed data
      */
-    public static FastSineTransformer createOrthogonal() {
-        return new FastSineTransformer(true);
+    public FastSineTransformer(final DstNormalization normalization) {
+        this.normalization = normalization;
     }
 
     /**
@@ -167,7 +103,7 @@ public class FastSineTransformer impleme
      * not a power of two, or the first element of the data array is not zero
      */
     public double[] transform(final double[] f, final TransformType type) {
-        if (orthogonal) {
+        if (normalization == DstNormalization.ORTHOGONAL_DST_I) {
             final double s = FastMath.sqrt(2.0 / f.length);
             return TransformUtils.scaleArray(fst(f), s);
         }
@@ -35,42 +35,10 @@ import org.apache.commons.math.util.Fast
  * There are several variants of the discrete sine transform. The present
  * implementation corresponds to DST-I, with various normalization conventions,
- * which are described below. <strong>It should be noted that regardless to the
- * convention, the first element of the dataset to be transformed must be
- * zero.</strong>
+ * which are specified by the parameter {@link DstNormalization}.
+ * <strong>It should be noted that regardless to the convention, the first
+ * element of the dataset to be transformed must be zero.</strong>
  * </p>